# -*- coding: utf-8 -*-

"""
Smashtheque API Wrapper
~~~~~~~~~~~~~~~~~~~
A basic wrapper for the Smashtheque API.
:copyright: (c) 2021-present Retropen-Bar
:license: MIT, see LICENSE for more details.
"""

__title__ = 'smashtheque'
__author__ = 'Retropen-Bar'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021-present Retropen-Bar'
__version__ = '0.0.1'



from setuptools import setup
import re

requirements = []
with open('requirements.txt') as f:
  requirements = f.read().splitlines()

version = ''
with open('smashtheque/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

readme = ''
with open('README.md') as f:
    readme = f.read()

setup(name='smashtheque',
      author='Retropen-Bar',
      url='https://github.com/Retropen-Bar/pysmashtheque',
      project_urls={
        "Website": "https://www.smashtheque.fr",
        "Issue tracker": "https://github.com/Retropen-Bar/pysmashtheque/issues",
      },
      version=version,
      packages=['smashtheque'],
      license='MIT',
      description='A Python wrapper for the Smashtheque API',
      long_description=readme,
      long_description_content_type="text/markdown",
      include_package_data=True,
      install_requires=requirements,
      python_requires='>=3.5.3',
      classifiers=[
        'Development Status :: 1 - Planning',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
      ]
)
